@@ -430,6 +430,14 @@ void ssl_hook_CloseConnection(conn_rec *conn)
     if (ssl == NULL)
         return;
 
+    /*
+     * First make sure that no more data is pending in Apache's BUFF,
+     * because when it's (implicitly) flushed later by the ap_bclose()
+     * calls of Apache it would lead to an I/O error in the browser due
+     * to the fact that the SSL layer was already removed by us.
+     */
+    ap_bflush(conn->client);
+
     /*
      * Now close the SSL layer of the connection. We've to take
      * the TLSv1 standard into account here:
